"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConsoleRemotePlugin = void 0;
const _ = require("lodash");
const readPkg = require("read-pkg");
const semver = require("semver");
const webpack = require("webpack");
const constants_1 = require("../constants");
const shared_modules_1 = require("../shared-modules");
const SchemaValidator_1 = require("../validation/SchemaValidator");
const ValidationResult_1 = require("../validation/ValidationResult");
const ConsoleAssetPlugin_1 = require("./ConsoleAssetPlugin");
const loadPackageManifest = (moduleName) => 
// eslint-disable-next-line @typescript-eslint/no-var-requires
require(`${moduleName}/package.json`);
const validatePackageFileSchema = (pkg) => {
    const schema = (0, ConsoleAssetPlugin_1.loadSchema)('plugin-package.json');
    const validator = new SchemaValidator_1.SchemaValidator('package.json');
    if (pkg.consolePlugin) {
        validator.validate(schema, pkg.consolePlugin, 'pkg.consolePlugin');
        validator.assert.validDNSSubdomainName(pkg.consolePlugin.name, 'pkg.consolePlugin.name');
        validator.assert.validSemverString(pkg.consolePlugin.version, 'pkg.consolePlugin.version');
        if (_.isPlainObject(pkg.consolePlugin.dependencies)) {
            Object.entries(pkg.consolePlugin.dependencies).forEach(([depName, versionRange]) => {
                validator.assert.validSemverRangeString(versionRange, `pkg.consolePlugin.dependencies['${depName}']`);
            });
        }
    }
    else {
        validator.result.addError('pkg.consolePlugin object is missing');
    }
    return validator.result;
};
const validateConsoleProvidedSharedModules = (pkg, sdkPkg = loadPackageManifest('@openshift-console/dynamic-plugin-sdk')) => {
    const pluginDeps = Object.assign(Object.assign({}, pkg.devDependencies), pkg.dependencies);
    const result = new ValidationResult_1.ValidationResult('package.json');
    shared_modules_1.sharedPluginModules.forEach((moduleName) => {
        // Skip modules for which a fallback (different) version can be provided by the plugin.
        // Also skip modules which are not explicitly listed in the plugin's dependencies.
        if (shared_modules_1.sharedPluginModulesMetadata[moduleName].allowFallback || !pluginDeps[moduleName]) {
            return;
        }
        const providedVersionRange = sdkPkg.dependencies[moduleName];
        const consumedVersion = loadPackageManifest(moduleName).version;
        if (semver.validRange(providedVersionRange) && semver.valid(consumedVersion)) {
            result.assertThat(semver.satisfies(consumedVersion, providedVersionRange), `Console provides shared module ${moduleName} ${providedVersionRange} but plugin uses version ${consumedVersion}`);
        }
    });
    return result;
};
/**
 * Generates Console dynamic plugin remote container and related assets.
 *
 * Default configuration for modules shared between the Console application and its dynamic plugins:
 * - shared modules are treated as singletons
 * - plugins won't bring their own fallback version of shared modules
 *
 * If you're facing `ExtensionValidator` related issues, set the `validateExtensionIntegrity` option
 * to `false` or pass `CONSOLE_PLUGIN_SKIP_EXT_VALIDATOR=true` env. variable to your webpack command.
 *
 * @see {@link sharedPluginModulesMetadata}
 */
class ConsoleRemotePlugin {
    constructor(options = {}) {
        var _a, _b, _c, _d;
        this.pkg = readPkg.sync({ normalize: false });
        this.options = {
            validatePackageSchema: (_a = options.validatePackageSchema) !== null && _a !== void 0 ? _a : true,
            validateSharedModules: (_b = options.validateSharedModules) !== null && _b !== void 0 ? _b : true,
            validateExtensionSchema: (_c = options.validateExtensionSchema) !== null && _c !== void 0 ? _c : true,
            validateExtensionIntegrity: (_d = options.validateExtensionIntegrity) !== null && _d !== void 0 ? _d : true,
        };
        if (this.options.validatePackageSchema) {
            validatePackageFileSchema(this.pkg).report();
        }
        if (this.options.validateSharedModules) {
            validateConsoleProvidedSharedModules(this.pkg).report();
        }
    }
    apply(compiler) {
        const logger = compiler.getInfrastructureLogger(ConsoleRemotePlugin.name);
        const publicPath = `/api/plugins/${this.pkg.consolePlugin.name}/`;
        const containerName = this.pkg.consolePlugin.name;
        const remoteEntryCallback = 'window.loadPluginEntry';
        // Validate webpack options
        if (compiler.options.output.publicPath !== undefined) {
            logger.warn(`output.publicPath is defined, but will be overridden to ${publicPath}`);
        }
        if (compiler.options.output.uniqueName !== undefined) {
            logger.warn(`output.uniqueName is defined, but will be overridden to ${containerName}`);
        }
        const containerLibrary = {
            type: 'jsonp',
            name: remoteEntryCallback,
        };
        const containerModules = _.mapValues(this.pkg.consolePlugin.exposedModules || {}, (moduleRequest, moduleName) => ({
            import: moduleRequest,
            name: `exposed-${moduleName}`,
        }));
        // https://webpack.js.org/plugins/module-federation-plugin/#sharing-hints
        const sharedModules = Object.entries(shared_modules_1.sharedPluginModulesMetadata).reduce((acc, [moduleRequest, moduleMetadata]) => {
            const adaptedMetadata = _.defaults({}, moduleMetadata, {
                singleton: true,
                allowFallback: false,
            });
            const moduleConfig = {
                singleton: adaptedMetadata.singleton,
            };
            if (!adaptedMetadata.allowFallback) {
                moduleConfig.import = false;
            }
            acc[moduleRequest] = moduleConfig;
            return acc;
        }, {});
        compiler.options.output.publicPath = publicPath;
        compiler.options.output.uniqueName = containerName;
        // Generate webpack federated module container assets
        new webpack.container.ModuleFederationPlugin({
            name: containerName,
            library: containerLibrary,
            filename: constants_1.remoteEntryFile,
            exposes: containerModules,
            shared: sharedModules,
        }).apply(compiler);
        // ModuleFederationPlugin does not generate a container entry when the provided
        // exposes option is empty; we fix that by invoking the ContainerPlugin manually
        if (_.isEmpty(containerModules)) {
            new webpack.container.ContainerPlugin({
                name: containerName,
                library: containerLibrary,
                filename: constants_1.remoteEntryFile,
                exposes: containerModules,
            }).apply(compiler);
        }
        // Generate and/or post-process Console plugin assets
        new ConsoleAssetPlugin_1.ConsoleAssetPlugin(this.pkg, remoteEntryCallback, this.options.validateExtensionSchema, this.options.validateExtensionIntegrity &&
            process.env.CONSOLE_PLUGIN_SKIP_EXT_VALIDATOR !== 'true').apply(compiler);
    }
}
exports.ConsoleRemotePlugin = ConsoleRemotePlugin;
//# sourceMappingURL=ConsoleRemotePlugin.js.map